@@ -26,16 +26,17 @@ test_get_adi_arg_tibble <- function(geography,
       state, 
       county, 
       zcta, 
-      geography, 
+      geography,
+      year,
       dataset,
       exec_arg_tibble
     )
   
-  tidyr::crossing(exec_arg_tibble, ref_area$state_county)
+  cross_args(exec_arg_tibble, ref_area$state_county, geography, year, dataset)
 }
 
 
-testvars_acs2015 <- c("B11005_001",
+testvars_acs2014 <- c("B11005_001",
                       "B15003_001", "B15003_002", "B15003_003", "B15003_004",
                       "B15003_005", "B15003_006", "B15003_007", "B15003_008",
                       "B15003_009", "B15003_010", "B15003_011", "B15003_012",
@@ -62,7 +63,7 @@ test_that("call tibble for geoids is correct", {
     test_get_adi_arg_tibble(
       geography = "state",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = test_geoids,
       state = NULL,
       county = NULL,
@@ -70,13 +71,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "state",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -89,7 +90,7 @@ test_that("call tibble for geoids is correct", {
     test_get_adi_arg_tibble(
       geography = "county",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = test_geoids,
       state = NULL,
       county = NULL,
@@ -97,13 +98,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "county",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -118,7 +119,7 @@ test_that("call tibble for geoids is correct", {
     test_get_adi_arg_tibble(
       geography = "tract",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = test_geoids,
       state = NULL,
       county = NULL,
@@ -126,13 +127,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "tract",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -150,7 +151,7 @@ test_that("call tibble for geoids is correct", {
     test_get_adi_arg_tibble(
       geography = "block group",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = test_geoids,
       state = NULL,
       county = NULL,
@@ -158,13 +159,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "block group",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -188,7 +189,7 @@ test_that("call tibble for states only is correct", {
     test_get_adi_arg_tibble(
       geography = "state",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = c("de", "dc", "ct"),
       county = NULL,
@@ -196,13 +197,13 @@ test_that("call tibble for states only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "state",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -216,7 +217,7 @@ test_that("call tibble for states only is correct", {
     test_get_adi_arg_tibble(
       geography = "county",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = c("de", "dc", "ct"),
       county = NULL,
@@ -224,13 +225,13 @@ test_that("call tibble for states only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "county",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -248,7 +249,7 @@ test_that("call tibble for states only is correct", {
     test_get_adi_arg_tibble(
       geography = "tract",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = c("de", "dc", "ct"),
       county = NULL,
@@ -256,13 +257,13 @@ test_that("call tibble for states only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "tract",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -277,7 +278,7 @@ test_that("call tibble for states only is correct", {
     test_get_adi_arg_tibble(
       geography = "block group",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = c("de", "dc", "ct"),
       county = NULL,
@@ -285,13 +286,13 @@ test_that("call tibble for states only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "block group",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -312,7 +313,7 @@ test_that("call tibble for one state and multiple counties is correct", {
     test_get_adi_arg_tibble(
       geography = "state",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = "oh",
       county = c("cuyahoga", "erie", "franklin", "lake"),
@@ -320,13 +321,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "state",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -340,7 +341,7 @@ test_that("call tibble for one state and multiple counties is correct", {
     test_get_adi_arg_tibble(
       geography = "county",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = "oh",
       county = c("cuyahoga", "erie", "franklin", "lake"),
@@ -348,13 +349,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "county",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -368,7 +369,7 @@ test_that("call tibble for one state and multiple counties is correct", {
     test_get_adi_arg_tibble(
       geography = "tract",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = "oh",
       county = c("cuyahoga", "erie", "franklin", "lake"),
@@ -376,13 +377,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "tract",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -397,7 +398,7 @@ test_that("call tibble for one state and multiple counties is correct", {
     test_get_adi_arg_tibble(
       geography = "block group",
       dataset = "acs5",
-      year = 2015,
+      year = 2014,
       geoid = NULL,
       state = "oh",
       county = c("cuyahoga", "erie", "franklin", "lake"),
@@ -405,13 +406,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_acs),
-      variables = list(testvars_acs2015),
-      year = 2015,
+      geography = "block group",
+      variables = list(testvars_acs2014),
+      year = 2014,
       survey = "acs5",
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
