@@ -27,11 +27,12 @@ test_get_adi_arg_tibble <- function(geography,
       county, 
       zcta, 
       geography, 
+      year,
       dataset,
       exec_arg_tibble
     )
   
-  tidyr::crossing(exec_arg_tibble, ref_area$state_county)
+  cross_args(exec_arg_tibble, ref_area$state_county, geography, year, dataset)
 }
 
 
@@ -60,12 +61,12 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "state",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -86,12 +87,12 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "county",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -112,12 +113,12 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "tract",
       variables = purrr::lmap(vars2000, rep, 4),
       sumfile = c(rep("sf1", 4), rep("sf3", 4)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -142,12 +143,12 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "block group",
       variables = purrr::lmap(vars2000, rep, 72),
       sumfile = c(rep("sf1", 72L), rep("sf3", 72L)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -191,12 +192,12 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "state",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -218,12 +219,12 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "county",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -245,12 +246,12 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "tract",
       variables = purrr::lmap(vars2000, rep, 3L),
       sumfile = c(rep("sf1", 3L), rep("sf3", 3L)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -276,12 +277,12 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "block group",
       variables = purrr::lmap(vars2000, rep, 12L),
       sumfile = c(rep("sf1", 12L), rep("sf3", 12L)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -318,12 +319,12 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "state",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -345,12 +346,12 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "county",
       variables = vars2000,
       sumfile = c("sf1", "sf3"),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -372,12 +373,12 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "tract",
       variables = purrr::lmap(vars2000, rep, 4L),
       sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -404,12 +405,12 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial),
+      geography = "block group",
       variables = purrr::lmap(vars2000, rep, 4L),
       sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
       year = 2000,
       output = "tidy",
       keep_geo_vars = FALSE,
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
